@@ -322,7 +322,7 @@ class Local(object):
         roles.reverse()
 
         if self.repo is not None:
-            self.mirror()
+            self.mirror(list(set(self.roles).union(set(roles))))
         self.build(roles)
 
         change_packages = self.get_new_packages()
